import { VisualizationTypes } from "@gooddata/sdk-ui";
import { isOneOfTypes } from "../_util/common.js";
import { ROTATE_NEGATIVE_90_DEGREES, ALIGN_LEFT, ALIGN_RIGHT } from "../../constants/axisLabel.js";
const axisNameConfigGetter = (chartOptions) => (axisNamePrefix) => (chartOptions?.[`${axisNamePrefix}Axes`] ?? []).map((axis) => {
    if (!axis) {
        return {};
    }
    return {
        title: getHighchartsAxisTitleConfiguration(chartOptions, axis, axisNamePrefix),
    };
});
function getHighchartsAxisTitleConfiguration(chartOptions, axis, axisNamePrefix) {
    const isYAxis = axisNamePrefix === "y";
    const opposite = axis?.opposite ?? false;
    const axisPropsKey = (opposite ? `secondary_${axisNamePrefix}AxisProps` : `${axisNamePrefix}AxisProps`);
    const axisNameConfig = chartOptions?.[axisPropsKey]?.name ?? {};
    const title = {};
    if (axisNameConfig.position) {
        title.align = axisNameConfig.position; // low | middle | high
    }
    // config.visible should be true/undefined by default
    if (axisNameConfig.visible === false) {
        title.text = "";
    }
    // opposite Y axis in combo, column and line chart
    // should be rotated the same way as its counterpart
    // and text alignment reversed from default
    if (opposite &&
        isYAxis &&
        isOneOfTypes(chartOptions.type, [
            VisualizationTypes.COMBO,
            VisualizationTypes.COMBO2,
            VisualizationTypes.COLUMN,
            VisualizationTypes.LINE,
        ])) {
        title.rotation = Number(ROTATE_NEGATIVE_90_DEGREES);
        if (title.align === "low") {
            title.textAlign = ALIGN_LEFT;
        }
        else if (title.align === "high") {
            title.textAlign = ALIGN_RIGHT;
        }
    }
    return title;
}
export function getAxisNameConfiguration(chartOptions) {
    const configGetter = axisNameConfigGetter(chartOptions);
    return {
        xAxis: configGetter("x"),
        yAxis: configGetter("y"),
    };
}
//# sourceMappingURL=getAxisNameConfiguration.js.map